<?php
/*
* 2007-2014 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2014 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

if (!defined('_PS_VERSION_'))
	exit;
 
class StNoImage extends Module
{
    private $_html = '';
    public $fields_form;
    public $fields_value;
    private $_prefix_st = 'ST_NO_IMAGE_';
    public $tabs;
    public $process = array(
            'categories' => array('dir' => _PS_CAT_IMG_DIR_),
            'manufacturers' => array('dir' => _PS_MANU_IMG_DIR_),
            'suppliers' => array('dir' => _PS_SUPP_IMG_DIR_),
            'products' => array('dir' => _PS_PROD_IMG_DIR_),
            'stores' => array('dir' => _PS_STORE_IMG_DIR_),
        );
	function __construct()
    {
		$this->name           = 'stnoimage';
		$this->tab            = 'front_office_features';
		$this->version        = '1.0.1';
		$this->author         = 'SUNNYTOO.COM';
		$this->need_instance  = 0;
		$this->bootstrap 	  = true;
		parent::__construct();

		$this->displayName = $this->l('Generate No Image Available Image');
		$this->description = $this->l('If some No Image Available are not exists, you can use this module to generate them without regenerating all thumbnails.');
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);

        $this->tabs = array(
            array('id'  => '0', 'name' => $this->l('General')),
            array('id'  => '1', 'name' => $this->l('About ST-themes')),
        );
	}

    protected function _regenerateNoPictureImages($dir, $type, $languages)
    {
        $errors = array();
        $generate_hight_dpi_images = (bool)Configuration::get('PS_HIGHT_DPI');

        foreach ($type as $image_type) {
            foreach ($languages as $language) {
                $file = $dir.$language['iso_code'].'.jpg';
                if (!file_exists($file)) {
                    $file = _PS_PROD_IMG_DIR_.Language::getIsoById((int)Configuration::get('PS_LANG_DEFAULT')).'.jpg';
                }
                if (!file_exists($dir.$language['iso_code'].'-default-'.stripslashes($image_type['name']).'.jpg')) {
                    if (!ImageManager::resize($file, $dir.$language['iso_code'].'-default-'.stripslashes($image_type['name']).'.jpg', (int)$image_type['width'], (int)$image_type['height'])) {
                        $errors[] = sprintf($this->l('Error when generate no picture for %s %s.'), $language['iso_code'], $image_type['name']);
                    }

                    if ($generate_hight_dpi_images) {
                        if (!ImageManager::resize($file, $dir.$language['iso_code'].'-default-'.stripslashes($image_type['name']).'2x.jpg', (int)$image_type['width']*2, (int)$image_type['height']*2)) {
                            $errors[] = sprintf($this->l('Error when generate hight dpi no picture for %s %s.'), $language['iso_code'], $image_type['name']);
                        }
                    }
                }
            }
        }
        return $errors;
    }
    protected function _jianChaNoPictureImages($dir, $type, $languages)
    {
        $count = 0;
        foreach ($type as $image_type) {
            foreach ($languages as $language) {
                if (!file_exists($dir.$language['iso_code'].'-default-'.stripslashes($image_type['name']).'.jpg')) {
                    $count++;
                }
            }
        }
        return $count;
    }
    public function getContent()
    {
        $this->context->controller->addCSS(($this->_path).'views/css/admin.css');
        $this->context->controller->addJS(($this->_path).'views/js/admin.js');

        if(Tools::getValue('act')=='generate_no_image')
        {
            $res = array();
            $languages = Language::getLanguages(false);
            foreach ($this->process as $pk => $pv) {
                $nopictures_error = $this->_regenerateNoPictureImages($pv['dir'],ImageType::getImagesTypes($pk),$languages);
                if(is_array($nopictures_error) && count($nopictures_error))
                    $res = array_merge($res, $nopictures_error);
            }
            if(count($res))
                $this->_html .= $this->displayError($res);
            else
                $this->_html .= $this->displayConfirmation($this->l('All "No Image Available" has been generated.'));
        }
        
        $this->initFieldsForm();
        $helper = $this->initForm();
        Media::addJsDef(array(
            'id_tab_index' => Tools::getValue('id_tab_index', 0),
        ));
        return $this->_html.'<div class="tabbable row sttab">'.$this->initTab().'<div class="col-xs-12 col-lg-10 tab-content">'.$helper->generateForm($this->fields_form).'</div></div>';
    }

    public function initTab()
    {
        $html = '<div class="st_sidebar col-xs-12 col-lg-2"><ul class="nav nav-tabs">';
        foreach($this->tabs AS $tab)
            $html .= '<li class="nav-item"><a href="javascript:;" title="'.$tab['name'].'" data-fieldset="'.$tab['id'].'">'.$tab['name'].'</a></li>';
        $html .= '</ul></div>';
        return $html;
    }
    protected function initFieldsForm()
    {
        $this->fields_form[0]['form'] = array(
            'legend' => array(
                'title' => $this->l('General:'),
                'icon' => 'icon-cogs'
            ),
            'input' => array(
                array(
                    'type' => 'hidden',
                    'name' => 'id_tab_index',
                    'default_value' => 0,
                ),
                'no_image' => array(
                    'type' => 'html',
                    'id' => '',
                    'label' => $this->l('Information'),
                    'name' => '',
                ),
            ),
        );
        $this->fields_form[1]['form'] = array(
            'legend' => array(
                'title' => $this->l('About ST-THEMES:'),
                'icon' => 'icon-cogs'
            ),
            'input' => array(
                array(
                    'type' => 'html',
                    'id' => '',
                    'label' => '',
                    'name' => 'This free module was created by <a href="https://www.sunnytoo.com" target="_blank">ST-THEMES</a>, it\'s not allow to sell it, it\'s also not allow to create new modules based on it. <br/>Check more <a href="https://www.sunnytoo.com/blogs?term=743&orderby=date&order=desc" target="_blank">free modules</a>, <a href="https://www.sunnytoo.com/product-category/prestashop-modules" target="_blank">advanced paid modules</a> and <a href="https://www.sunnytoo.com/product-category/prestashop-themes" target="_blank">themes(transformer theme and panda  theme)</a> created by <a href="https://www.sunnytoo.com" target="_blank">ST-THEMES</a>.',
                ),
            ),
        );
        $languages = Language::getLanguages(false);
        $no_image_count = 0;
        foreach ($this->process as $pk => $pv) {
            $no_image_count += $this->_jianChaNoPictureImages($pv['dir'],ImageType::getImagesTypes($pk),$languages);
        }
        if($no_image_count)
            $this->fields_form[0]['form']['input']['no_image']['name'] .= sprintf($this->l('%s "No Image Available" images are not existing.'), $no_image_count).'<a href="'.AdminController::$currentIndex.'&configure='.$this->name.'&act=generate_no_image&token='.Tools::getAdminTokenLite('AdminModules').'" class="btn btn-default">'.$this->l('Click here to generate "No Image Available" images.').'</a>';
        else
            $this->fields_form[0]['form']['input']['no_image']['name'] .= $this->l('All "No Image Available" images are existing.').'<a href="'.AdminController::$currentIndex.'&configure='.$this->name.'&act=generate_no_image&token='.Tools::getAdminTokenLite('AdminModules').'" class="btn btn-default">'.$this->l('Click here to regenerate "No Image Available" images.').'</a>';
    }
    protected function initForm()
    {
        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table =  $this->table;
        $helper->module = $this;
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
        $helper->default_form_language = $lang->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'savestnoimage';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );
        return $helper;
    }
    
    private function getConfigFieldsValues()
    {
        $fields_values = array(
        );
        $fields_values['id_tab_index'] = Tools::getValue('id_tab_index', 0);
        return $fields_values;
    }

}